summaryrefslogtreecommitdiff
path: root/test.sh
diff options
context:
space:
mode:
authorMarcello Stanisci <stanisci.m@gmail.com>2019-04-16 13:47:45 +0200
committerMarcello Stanisci <stanisci.m@gmail.com>2019-04-16 13:47:45 +0200
commiteff108f616d4f053eaa4950022e4ff2ad06866c8 (patch)
treea5393b7b31d76f9cdcbbe4b9f07f476a594be89d /test.sh
parent9eb2da5236166f37d68310cdd7c1e889a992e384 (diff)
downloaddeployment-eff108f616d4f053eaa4950022e4ff2ad06866c8.tar.gz
deployment-eff108f616d4f053eaa4950022e4ff2ad06866c8.tar.bz2
deployment-eff108f616d4f053eaa4950022e4ff2ad06866c8.zip
typo
Diffstat (limited to 'test.sh')
-rwxr-xr-xtest.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/test.sh b/test.sh
index 9f10f6f..313335f 100755
--- a/test.sh
+++ b/test.sh
@@ -3,10 +3,10 @@
# Every "blue/green" setup relies on a common user that keeps
# all the shared data (keys, for example). In our setup, test-*
# and demo-* rely on the users 'test' and 'demo'. This script
# automates the configuration of the 'demo' user.
if ! test "test" = $(whoami); then
- echo This script can only be run by the 'demo' user, exiting..
+ echo This script can only be run by the 'test' user, exiting..
exit 1
fi
@@ -3,10 +3,10 @@
# all the shared data (keys, for example). In our setup, test-*
# and demo-* rely on the users 'test' and 'demo'. This script
-# automates the configuration of the 'demo' user.
+# automates the configuration of the 'test' user.
if ! test "test" = $(whoami); then